Module: Paperclip

Defined in:
lib/reduceds3.rb,
lib/soapbox/paperclip.rb

Overview

allow us to define Amazon storage type to use on Amazon for each style, by introducing a 's3_reduced' key

Example:

has_attached_file :image, :storage => :reduceds3, :s3_credentials => Rails.root.join("config/s3.yml"), :s3_permissions => 'public-read', :s3_protocol => 'http', :path => ":id.:style.:extension" :styles => { :original => => "500x375>", :s3_reduced => false, :large => => "300x250", :format => :png, :s3_reduced => true, :small => => "100x75", :format => :png, :s3_reduced => true }, :processors => [:thumbnail], :default_style => :original

Defined Under Namespace

Modules: Storage Classes: Attachment